PLink is a full featured graphical editor for knot and link projections,
using the cross-platform GUI toolkit Tk.  The primary focus is on
piecewise-linear link projections, but it also supports a "smooth
mode" and can export images in PostScript, PDF, SVG, and TikZ formats.
See the `PLink home page <https://t3m.math.uic.edu/plink/doc>`_
for complete details.

This is a pure Python module and you can install it via
`pip <https://pip.pypa.io/en/latest/>`_.
See `the documentation
<https://t3m.math.uic.edu/plink/doc/installing>`_
for more.

You can browse the source code `here <https://github.com/3-manifolds/PLink>`_.


License
========================

Copyright 2008-present by Marc Culler, Nathan Dunfield, and others.

All parts of this package are released under the
`GNU General Public License, version 2 <http://www.gnu.org/licenses/gpl-2.0.txt>`_
or (at your discretion) any later version as
published by the Free Software Foundation.


Acknowledgements
========================

The development of this program was partially supported by the US
National Science Foundation under grants DMS0608567, DMS0504975,
DMS0204142, and others.
